@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #这里是引用库
 # from .config import *
-from .tkitbilstm import *
+from .bilstm import BiLSTMAttention
 
 
